// components/Input/index.tsx

import { useState } from 'react';
import { UseFormRegisterReturn } from 'react-hook-form';
import VisibilityIcon from '@mui/icons-material/Visibility';
import VisibilityOffIcon from '@mui/icons-material/VisibilityOff';

interface InputProps extends React.InputHTMLAttributes<HTMLInputElement> {
  type?: string;
  icon?: string;
  label?: string;
  placeholder?: string;
  register?: UseFormRegisterReturn;
  name: string;
  id?: string;
  error?: string;
  autoComplete?: string;
  borderRadius?: string;
}

const Input = ({
  type = 'text',
  icon,
  label,
  name,
  id,
  placeholder = '',
  register,
  error = '',
  value,
  autoComplete,
  borderRadius = 'rounded-full',
  ...rest
}: InputProps) => {
  const inputId = id || name;
  const [passwordState, setPasswordState] = useState(true)
  
  return (
    <div className="flex flex-col w-full">
      {label && (
        <label htmlFor={inputId} className="mb-2 text-sm font-medium text-gray-700">
          {label}
        </label>
      )}
      <div className="relative">
        <input
          id={inputId}
          type={passwordState ? type : "text"}
          name={name}
          placeholder={placeholder}
          autoComplete={autoComplete}
          value={value}
          {...register}
          className={`w-full px-4 py-2 text-sm bg-white text-gray-900 border ${
            error ? 'border-red-500' : 'border-gray-300'
          } ${borderRadius} focus:outline-none`}
          {...rest}
        />
        {type === "password" &&  (
          <span className="absolute right-4 top-1/2 transform -translate-y-1/2" onClick={()=>setPasswordState(!passwordState)}>
           {passwordState ? <VisibilityOffIcon htmlColor='#6F757E' fontSize="medium"/>:<VisibilityIcon htmlColor='#6F757E' fontSize='medium'/>}
          </span>
        )
      }
        {icon && type !== "password" && (
          <span className="absolute right-4 top-1/2 transform -translate-y-1/2">
            <img src={icon} alt="icon" className="h-5 w-5" />
          </span>
        )}
      </div>
      {error && <p className="mt-2 text-sm text-red-500">{error}</p>}
    </div>
  );
};

export default Input;
