import React, { useState } from "react";
import DeleteIcon from '@mui/icons-material/Delete';
import Modal from "../Modal";

interface CartItemProps {
    name: string;
    deliveryDate?: string;
    price: number;
    removeItem: () => void;
  }
  
  const CartItem: React.FC<CartItemProps> = ({ name, deliveryDate, price, removeItem }) => {
    const [showModal, setShowModal] = useState(false);
    
    const onDecrease = () => {
      setShowModal(true);
    }
    
    return (
      <>
        <div className="bg-white p-4 mb-4 border-b-2 border-grey">
          {/* Item Name and Delivery Info */}
          <div>
            <p className="text-gray-900 font-semibold text-base">{name}</p>
            {
              deliveryDate &&
              <p className="text-sm text-gray-500">Previsto da Entrega: {deliveryDate}</p>
            }
          </div>
    
          {/* Quantity Control and Price */}
          <div className="flex items-center justify-between mt-2">
            <p className="text-gray-800 font-semibold">R${price.toFixed(2)}</p>
            <DeleteIcon className="text-red-500 cursor-pointer" onClick={onDecrease} />
          </div>
        </div>
        
        <Modal
          isOpen={showModal}
          title="Remover item do carrinho"
          content={`Tem certeza que deseja remover ${name} do carrinho?`}
          onCancel={() => setShowModal(false)}
          confirmText="Remover"
          onConfirm={() => {
            removeItem()
            setShowModal(false)
          }}
        />
      </>
    );
  };

  export default CartItem;