import React from 'react';
import { useNavigate } from 'react-router-dom';
import SearchIcon from '@mui/icons-material/Search';
import ShoppingCartIcon from '@mui/icons-material/ShoppingCart';
import HistoryIcon from '@mui/icons-material/History';
import { useBuyerStore } from '../../store';

// Define the props for each icon
interface IconButtonProps {
  icon: React.ElementType; // Expect a Material-UI icon component
  label: string;
  route: string; // Add a route prop
  badgeCount?: number; // Add an optional badgeCount prop
}

const IconButton: React.FC<IconButtonProps> = ({ icon: Icon, label, route, badgeCount }) => {
  const navigate = useNavigate();

  const handleClick = () => {
    navigate(route);
  };
  
  return (
    <div className="relative flex flex-col items-center justify-center p-2 cursor-pointer" onClick={handleClick}>
      <Icon className="text-orange-500" style={{ fontSize: 32 }} />
      {badgeCount !== undefined && badgeCount > 0 && (
        <div className="absolute -top-1 -right-1 bg-orange-500 text-white rounded-full h-4 w-4 flex items-center justify-center text-xs">
          {badgeCount}
        </div>
      )}
      <span className="mt-1 text-orange-500 hidden sm:flex text-xs font-semibold justify-center items-center">
        {label}
      </span>
    </div>
  );
};

const IconMenu: React.FC = () => {
  const cart = useBuyerStore((state) => state.cart);
  
  return (
    <div className="fixed bottom-0 left-0 right-0 flex justify-around bg-white border-t-2 border-orange-400 py-2 shadow-lg">
      <IconButton 
        icon={SearchIcon} 
        label="Buscar peças" 
        route="/mecanico/busca"
      />
      <IconButton 
        icon={ShoppingCartIcon} 
        label="Carrinho de Compras" 
        route="/mecanico/carrinho"
        badgeCount={cart.length}
      />
      <IconButton 
        icon={HistoryIcon} 
        label="Histórico de Compras" 
        route="/mecanico/historico"
      />
    </div>
  );
};

export default IconMenu;