import Input from "../../components/Input";
import Dropdown from "../../components/Dropdown";
import CloseIcon from "@mui/icons-material/Close";
import { PieceData } from "../../pages/cadastroCarro/cadastroCarro";

interface optionDto {
  value: string;
  label: string;
}

interface PieceFormProps {
  index: number;
  form: PieceData;
  errors: Partial<PieceData>;
  carPart: optionDto[];
  handleInputChange: (index: number, e: React.ChangeEvent<HTMLInputElement>) => void;
  handleDelete: (index: number) => void;
}

const PieceForm = ({ index, form, errors, carPart, handleInputChange, handleDelete }: PieceFormProps) => {
  return (
    <div className="border-[1px] rounded-lg shadow-sm relative mt-4">
      <CloseIcon
        onClick={() => handleDelete(index)}
        className="absolute top-2 right-2 cursor-pointer hover:text-red-600"
      />
      <div className="p-4">
        <h3 className="text-lg font-semibold mb-4 ">Informações da peça</h3>
        <div className="grid grid-cols-3 gap-x-12 gap-y-6 ">
          <div>
            <Dropdown
              placeholder={"Nome da peça"}
              options={carPart}
              name="nome"
              value={form.nome}
              onOptionSelect={(option) =>
                handleInputChange(index, {
                  target: { name: "nome", value: option.value },
                } as unknown as React.ChangeEvent<HTMLInputElement>)
              }
            />
            {errors?.nome && <p className="text-red-500 mt-1">{errors.nome}</p>}
          </div>
          <div>
            <Input
              name="preco"
              type="number"
              placeholder="Preço"
              value={form.preco}
              onChange={(e) => handleInputChange(index, e)}
            />
            {errors?.preco && <p className="text-red-500 mt-1">{errors.preco}</p>}
          </div>
          <Input
            name="observacao"
            type="text"
            placeholder="Observação"
            value={form.observacao}
            onChange={(e) => handleInputChange(index, e)}
          />
        </div>
      </div>
    </div>
  );
};

export default PieceForm;