import { Stepper, Step, StepLabel, StepIconProps, styled } from '@mui/material';
import StepConnector, { stepConnectorClasses } from '@mui/material/StepConnector';

interface StepperProps {
  step: number;
}

function CustomStepIcon(props: StepIconProps) {
  const { active, completed } = props; 
  return (
    <div
      className={`w-6 h-6 rounded-full border-0 ${
        completed || active ? 'bg-white' : 'bg-white/50'
      }`}
    ></div>
  );
}

const CustomStepConnector = styled(StepConnector)(() => ({
  [`&.${stepConnectorClasses.active}`]: {
    [`& .${stepConnectorClasses.line}`]: {
      backgroundColor: '#fff',
    },
  },
  [`&.${stepConnectorClasses.completed}`]: {
    [`& .${stepConnectorClasses.line}`]: {
      backgroundColor: '#fff',
    },
  },
  [`& .${stepConnectorClasses.line}`]: {
    height: 5,
    width: 'calc(100% + 16.4px)',
    transform: 'translateY(-2px) translateX(-8.2px)',
    backgroundColor: 'rgb(255 255 255 / 0.5)',
  },
}));

function StepperComponent({ step }: StepperProps): JSX.Element {
  return (
    <div className="w-full mx-auto bg-orange-500 py-5 rounded-2xl  justify-center ">
      <Stepper 
        alternativeLabel
        activeStep={step} 
        connector={<CustomStepConnector />}
      >
        {[...Array(3)].map((_, index) => (
          <Step key={index}>
            <StepLabel
              StepIconComponent={CustomStepIcon}
            />
          </Step>
        ))}
      </Stepper>
    </div>
  );
}

export default StepperComponent;