import { useState, useEffect } from "react";
import CloseIcon from "@mui/icons-material/Close";

interface ToastProps {
  message: string;
  isOpen: boolean;
  isSuccess?: boolean;
}

function Toast({ message, isOpen, isSuccess = true }:ToastProps) {
  const [show, setShow] = useState(isOpen);

  const showToast = () => {
    setTimeout(() => {
      setShow(false);
    }, 5000);
  };

  useEffect(() => {
    showToast();
  }, []);

  return (
    show && (
      <div className={`fixed top-4 w-56 right-4 z-50 text-stone-900 ${isSuccess ? "bg-green-400" : "bg-red-500 "} px-4 py-3 rounded-md shadow-lg flex justify-between items-center space-x-4`}>
        <span className="">{message}</span>
        <button
          onClick={() => setShow(false)}
          className="text-stone-900 font-bold absolute right-1 top-0"
        >
          <CloseIcon style={{ fontSize: 16 }} />
        </button>
      </div>
    )
  );
}

export default Toast;
