import React from "react";
import CardDetalhePagamento from "../../components/CardDetalhePagamento";
import Button from "../../components/Button";
import CartItem from "../../components/ItemCarrinho";
import { useBuyerStore } from "../../store";
import ShoppingCartIcon from "@mui/icons-material/ShoppingCart";
import api from "../../services/api";
import { useNavigate } from "react-router-dom";

interface CartItem {
  id: number;
  name: string;
  price: number;
  quantity: number;
  deliveryDate: string;
}

const Carrinho: React.FC = () => {
  const [isLoading, setIsLoading] = React.useState(false);
  const cartItems = useBuyerStore((state) => state.cart);
  const navigate = useNavigate();

  const totalItems = cartItems.length;
  const totalPrice = cartItems.reduce((total, item) => total + item.price, 0);
  const deliveryFee = 0;

  const removePart = useBuyerStore((state) => state.removeFromCart);

  const today = new Date();
  today.setDate(today.getDate() + 4);
  const deliveryMock = today.toLocaleDateString("en-GB");

  const handleRealizarPedido = async () => {
    const postBody = {
      purchase_status_id: 0,
      description: "",
      partIds: cartItems.map((item) => {
        return {
          id: item.id,
        };
      }),
    };

    try {
      setIsLoading(true); // Inicia o estado de carregamento
      await api.post(`/purchase`, postBody);
      setIsLoading(false); // Finaliza o estado de carreg
      
      // Limpa o carrinho
      useBuyerStore.setState({ cart: [] });
      navigate("/mecanico/historico", {
        state: { createdPurchase: true }
      });
    } catch (error) {
      console.error(error);
    }
  };

  return (
    <div className="flex flex-col items-center h-full bg-orange-500">
      <div className="w-full max-w-md flex-grow flex flex-col items-center p-4 overflow-hidden h-full">
        <div className="mb-6 mt-4">
          <img
            src="/logoprojeto.png"
            alt="Logo"
            className="rounded-full w-24 h-24"
          />
        </div>
        <h2 className="text-2xl font-normal text-center text-white mb-6">
          Itens no Carrinho ({totalItems})
        </h2>
        <div className="w-full max-w-md bg-white rounded-lg shadow-lg p-6 flex flex-col flex-grow overflow-y-auto no-scrollbar">
          {cartItems.map((item) => (
            <CartItem
              name={`${item.part_type.enumerator} (${item.car.model.enumerator})`}
              price={item.price}
              removeItem={() => removePart(item)}
              key={item.id}
              deliveryDate={deliveryMock}
            />
          ))}

          {totalItems === 0 ? (
            <div className="flex flex-col items-center justify-center h-full text-center text-gray-500">
              <ShoppingCartIcon style={{ fontSize: 48 }} />
              <span>Adicione itens ao carrinho</span>
            </div>
          ) : (
            <div className="flex flex-col mb-4">
              <CardDetalhePagamento
                total={"R$" + totalPrice.toFixed(2)}
                taxaEntrega="Grátis"
                valorTotal={"R$" + (totalPrice + deliveryFee).toFixed(2)}
                numItens={totalItems}
              />
              <Button
                onClick={handleRealizarPedido}
                className={`bg-orange-400 text-white font-bold mt-4 py-4 rounded-full w-full ${
                  isLoading ? "opacity-70" : ""
                }`}
              >
                {isLoading ? "Finalizando pedido..." : "Realizar Pedido"}
              </Button>
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default Carrinho;
