import React from "react";
import { useLocation, useNavigate } from "react-router-dom";
import BackButton from "../../components/BackButton";
import ButtonHome from "../../components/ButtonHome";
import Toast from "../../components/Toast";

const Home: React.FC = () => {
  const navigate = useNavigate();

  const location = useLocation();
  const { createdCar } = location.state || {};

  const handleLogout = () => {
    navigate("/"); // <== voltar
  };

  return (
    <div className="relative flex flex-col justify-center items-center min-h-screen bg-[#FFF4EA]">
      <Toast message="Carro cadastrado com sucesso" isOpen={createdCar} />
      {/*botao de voltar*/}
      <div className="absolute top-6 left-6">
        <BackButton showModalOnBack={true} onConfirmBack={handleLogout} />
      </div>

      {/* logo */}
      <div className="flex justify-center mb-6">
        <img src="/logo.svg" alt="Logo" className="w-24 h-auto" />
      </div>

      {/* container */}
      <div className="w-full max-w-4xl bg-white p-14 rounded-lg shadow-lg">
        <h2 className="text-3xl font-bold text-gray-800 mb-2 text-center">
          Bem-vindo ao Buscapeças!
        </h2>
        <p className="text-gray-600 text-center text-sm mb-8">
          Por favor, selecione uma das opções abaixo
        </p>
        <div className="flex flex-row gap-14 justify-center items-center">
          <ButtonHome
            isFluid={true}
            onClick={() => navigate("/cadastro-carro")}
            icon="carro.png"
            customClass="max-h-[230px]"
          >
            <span className="text-center font-semibold text-lg mb-0">Cadastrar Veículo</span>
          </ButtonHome>

          <ButtonHome
            isFluid={true}
            onClick={() => navigate("/estoque")}
            icon="estoque.png"
            customClass="max-h-[230px]"
          >
            <span className="text-center font-semibold text-lg mb-1">Estoque</span>
          </ButtonHome>

          <ButtonHome
            isFluid={true}
            onClick={() => navigate("/relatorios")}
            icon="vendas.png"
            customClass="max-h-[230px]"
          >
            <span className="text-center font-semibold text-lg mb-1">Rendimentos</span>
          </ButtonHome>
        </div>
      </div>
    </div>
  );
};

export default Home;
