import React, { useEffect, useState } from "react";
import Input from "../../components/Input";
import Button from "../../components/Button";
import Header from "../../components/Header";
import { useLocation, useNavigate } from "react-router-dom";
import Toast from "../../components/Toast";
import api from "../../services/api";

interface Vendedor {
  cdv: string;
  nome: string;
  id: string;    
}


const HomeParcialAdmin: React.FC = () => {
    const navigate = useNavigate();
    const [searchTerm, setSearchTerm] = useState("");
    const [sellers, setSellers] = useState<Vendedor[]>([]);
    const location = useLocation();
    const { createdSeller } = location.state || {};

    const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        setSearchTerm(e.target.value);
    };

    // Lista de vendedores (apenas um mock do que vai ser puxado do back)
    useEffect(() => {
      const fetchSellers = async () => {
        const data = await api.get(`/seller`).then((response) => response.data).catch((error) => console.error('Error fetching brands: ', error))
                
        if (!data) {
          return;
        }
  
        const sellersAdapted = data.map(
          (item: { seller_code: string; company_name: string, user_id: string }) => {
            return {
              cdv: item.seller_code,
              nome: item.company_name,
              id: item.user_id
            };
          }
        );
  
        setSellers(sellersAdapted);
      };
  
      fetchSellers();
    }, []);

    const leftComponent = <h2 className="text-xl font-semibold ml-4">Vendedores</h2>;
    const centerComponent = (
        <div className = "w-full">
            <Input
                name="searchbar"
                value={searchTerm}
                onChange={handleChange}
                placeholder="Pesquisar"
                icon="searchIcon.svg"
            />
        </div>
    );
           
    // Dropdown suspeito
    const rightComponent = (
    <div>
        <Button customClass = "bg-transparent" >Super Admin</Button>
    </div>
    );

    
    return (
        <div className="relative flex-col items-center min-h-screen bg-[#FFF4EA] pb-6">
          <Toast message="Vendedor cadastrado com sucesso" isOpen={createdSeller} />
          
                <Header 
                leftComponent = {leftComponent}
                centerComponent = {centerComponent}
                rightComponent = {rightComponent}
                customClass="w-full mx-auto space-between space-x-20 p-6 place-items-center bg-transparent"
                />
            <div className="overflow-x-auto mx-auto max-w-7xl w-full bg-white p-5 rounded-lg shadow-md">
                <table className="min-w-80 border-collapse border border-gray-300 w-full">
                    <thead>
                        <tr>
                            <th className="border border-gray-300 p-2 text-left">CDV</th>
                            <th className="border border-gray-300 p-2 text-left">
                                <div className="flex justify-between items-center">
                                    Nome 
                                    <Button className="bg-accent text-white rounded-full w-60 h-10" onClick = {()=>navigate("/cadastro-ferrovelho")}>Cadastrar Vendedor</Button>
                                </div>
                            </th>
                        </tr>
                    </thead>
                    <tbody>
                    {sellers
                        .filter(vendedor => 
                            vendedor.nome.toLowerCase().includes(searchTerm.toLowerCase()) || 
                            vendedor.cdv.includes(searchTerm)
                        )
                        .map((vendedor) => (
                            <tr className="cursor-pointer" key={vendedor.id} onClick={()=>navigate(`/estoque?seller=${vendedor.id}`)}>
                                <td className="border border-gray-300 p-2">{vendedor.cdv}</td>
                                <td className="border border-gray-300 p-2">{vendedor.nome}</td>
                            </tr>
                        ))}
                    </tbody>
                </table>
            </div>
        </div>
    );
};

export default HomeParcialAdmin;