import { useEffect, useState } from "react";
import BackButton from "../../components/BackButton";
import { EditCar } from "../../components/EditCar";
import api from "../../services/api";
import { useParams } from "react-router-dom";
import { jwtDecode } from "jwt-decode";
import { DecodedToken } from "../../dtos/decodedToken";
import Loader from "../../components/Loader";
import { PieceData } from "../cadastroCarro/cadastroCarro";

export interface EditarCarroAdaptado {
  marca: number;
  ano: string;
  valor: string;
  modelo: number;
  data_de_compra: string;
  car_id: number;
  parts: PieceData[];
}

const VerPecasDoVeiculo = () => {
  const { car_id } = useParams();

  const [car, setCar] = useState<EditarCarroAdaptado | null>(null);
  const [isLoading, setIsLoading] = useState(true);

  const fetchCar = async (id: number) => {
    try {
      const token = localStorage.getItem("token");

      if (!token) {
        throw new Error("No token found");
      }

      const decoded = jwtDecode<DecodedToken>(token);
      const response = await api.get(`seller/${decoded.id}/car/${id}/parts`);

      const data = response.data;

      const parts = data?.parts.map((part: any) => ({
        nome: part.part_type_id,
        preco: part.price,
        id: part.id,
        observacao: part.description,
      }));

      const adaptedCar = {
        marca: data?.model.brand_id,
        ano: new Date(data?.release_year ?? 0).getFullYear().toString(),
        valor: data?.cost.toString(),
        modelo: data?.model.id,
        data_de_compra: data?.purchase_date,
        car_id: data?.id,
        parts: parts,
      };

      setCar(adaptedCar);
      setIsLoading(false);
    } catch (error) {
      console.error(error);
    }
  };

  useEffect(() => {
    fetchCar(Number(car_id));
  }, []);

  return (
    <div className="flex flex-col h-screen bg-amber-50">
      {/* Topo da página, botão voltar, logo e nome do ferro velho */}
      <div className="flex justify-between items-center p-8">
        <BackButton />
        <img className="mx-auto h-16" src="/logoprojeto.png" alt="Logo" />
        <h2 className="text-2xl font-semibold">
          {/* Função para buscar o nome do Ferro Velho*/}
        </h2>
      </div>
      <div>
        {!isLoading ? (
          <EditCar
            marca={car?.marca ?? 0}
            ano={car?.ano ?? ""}
            valor={car?.valor ?? ""}
            modelo={car?.modelo ?? 0}
            data_de_compra={car?.data_de_compra ?? ""}
            car_id={car?.car_id ?? 0}
            parts={car?.parts ?? []}
          />
        ) : (
          <Loader />
        )}
      </div>
    </div>
  );
};

export default VerPecasDoVeiculo;
