import { Routes, Route } from 'react-router-dom';
import HomeFerroVelho from '../pages/HomeFerroVelho';
import Login from '../pages/Login';
import LoginMecanico from '../pages/LoginMecanico';
import CadastroMecanico from '../pages/cadastroMecanico';
import ProtectedRoute from './ProtectedRoute';
import NotFound from '../pages/NotFound';
import Layout from '../layouts/Layout';
import CadastroFerrosVelhos from '../pages/cadastroFerroVelho/cadastroFerroVelhos';
import CadastroRepresentante from '../pages/cadastroRepresentante/cadastroRepresentante';
import LayoutMecanico from "../layouts/LayoutMecanico";
import MeuEstoque from "../pages/MeuEstoque";
import HomeParcialAdmin from "../pages/HomeParcialAdmin";
import CadastroCarro from "../pages/cadastroCarro/cadastroCarro";
import TabelaCarro from '../pages/TabelaCarro';
import VehiclePartSearch from "../pages/VehiclePartSearch";
import BuyerPurchases from "../pages/BuyerPurchases";
import Reports from "../pages/Reports";
import Carrinho from "../pages/Carrinho";
import EditarCarro from '../pages/editarCarro';

const AppRoutes = () => {
  return (
    <Routes>
      <Route element={<Layout />}>
        {/* Exemplo de rota pública */}
        <Route path="/mecanico-cadastro" element={<CadastroMecanico />} />
        <Route path="/mecanico" element={<LoginMecanico />} />
        <Route path="/" element={<Login />} />

        <Route element={<LayoutMecanico />}>
          <Route
            path="/mecanico/busca"
            element={
              <ProtectedRoute allowedRoles={["buyer", "admin"]}>
                <VehiclePartSearch />
              </ProtectedRoute>
            }
          />
          <Route
            path="/mecanico/historico"
            element={
              <ProtectedRoute allowedRoles={["buyer", "admin"]}>
                <BuyerPurchases />
              </ProtectedRoute>
            }
          />
          <Route
            path="/mecanico/carrinho"
            element={
              <ProtectedRoute allowedRoles={["buyer", "admin"]}>
                <Carrinho />
              </ProtectedRoute>
            }
          />
        </Route>

        <Route
          path="/home"
          element={
            <ProtectedRoute allowedRoles={["seller", "admin"]}>
              <HomeFerroVelho />
            </ProtectedRoute>
          }
        />

          <Route
          path="/estoque/:car_id"
          element={
            <ProtectedRoute allowedRoles={["seller", "admin"]}>
              <TabelaCarro />
            </ProtectedRoute>
          }
        />

        <Route
          path="/cadastro-carro"
          element={
            <ProtectedRoute allowedRoles={["seller", "admin"]}>
              <CadastroCarro />
            </ProtectedRoute>
          }
        />

        <Route
          path="/estoque"
          element={
            <ProtectedRoute allowedRoles={["seller", "admin"]}>
              <MeuEstoque />
            </ProtectedRoute>
          }
        />
        
        <Route
          path="/estoque/:car_id/editar"
          element={
            <ProtectedRoute allowedRoles={["seller", "admin"]}>
              <EditarCarro />
            </ProtectedRoute>
          }
        />

        <Route
          path="/relatorios"
          element={
            <ProtectedRoute allowedRoles={["seller", "admin"]}>
              <Reports />
            </ProtectedRoute>
          }
        />

        <Route
          path="/admin"
          element={
            <ProtectedRoute allowedRoles={["admin"]}>
              <HomeParcialAdmin />
            </ProtectedRoute>
          }
        />

        <Route
          path="/cadastro-ferrovelho"
          element={
            <ProtectedRoute allowedRoles={["admin"]}>
              <CadastroFerrosVelhos />
            </ProtectedRoute>
          }
        />

        <Route
          path="/cadastro-representante"
          element={
            <ProtectedRoute allowedRoles={["admin"]}>
              <CadastroRepresentante />
            </ProtectedRoute>
          }
        />

        <Route path="*" element={<NotFound />} />
      </Route>
    </Routes>
  );
};

export default AppRoutes;
