/* eslint-disable react-hooks/rules-of-hooks */
import { Navigate } from 'react-router-dom';
import { jwtDecode } from 'jwt-decode';
import { DecodedToken } from '../dtos/decodedToken';

interface ProtectedRouteProps {
  children: React.ReactNode;
  allowedRoles: string[];
}

const ProtectedRoute = ({ children, allowedRoles }: ProtectedRouteProps) => {
  const token = localStorage.getItem('token');
  if (!token) {
    return <Navigate to="/" />;
  }
  
  const decoded = jwtDecode<DecodedToken>(token);
  
  const userRole = decoded.role;
  
  if (!allowedRoles.includes(userRole)) {
    return <Navigate to="/404" />;
  }

  return children;
};

export default ProtectedRoute;
