export type Role = {
  id: number;
  enumerator: string;
  updated_at: string;
  created_at: string;
  users: User[];
};

export type User = {
  id?: number;
  username: string;
  email?: string;
  password: string;
  document_number?: string;
  is_active?: boolean;
  role_id?: number;
  updated_at?: string;
  created_at?: string;
  role?: Role;
  Seller?: Seller;
  Buyer?: Buyer;
};

export type Seller = {
  user_id: number;
  seller_code: string;
  company_name: string;
  trading_name: string;
  document_number: string;
  email: string;
  phone_country_code: string;
  phone_area_code: string;
  phone_number: string;
  street: string;
  neighborhood: string;
  number: string;
  city: string;
  state: string;
  complement: string;
  postal_code: string;
  updated_at: string;
  created_at: string;
  user: User;
  Car: Car[];
  purchase_part: PurchasePart[];
};

export type Buyer = {
  user_id?: number;
  company_name: string;
  trading_name: string;
  document_number: string;
  email: string;
  phone_country_code: string;
  phone_area_code: string;
  phone_number: string;
  street: string;
  neighborhood: string;
  number: string;
  city: string;
  state: string;
  complement: string;
  postal_code: string;
  updated_at?: string;
  created_at?: string;
  user?: User;
  purchases?: Purchase[];
};

export type Brand = {
  id: number;
  enumerator: string;
  updated_at: string;
  created_at: string;
  models: Model[];
};

export type Model = {
  id: number;
  enumerator: string;
  brand_id: number;
  updated_at: string;
  created_at: string;
  brand: Brand;
  cars: Car[];
};

export type Car = {
  id: number;
  seller_id: number;
  model_id: number;
  release_year: string;
  cost: number;
  purchase_date: string;
  sale_date: string;
  updated_at: string;
  created_at: string;
  seller: Seller;
  model: Model;
  parts: Part[];
};

export type PartStatus = {
  id: number;
  enumerator: string;
  updated_at: string;
  created_at: string;
  parts: Part[];
};

export type PartType = {
  id: number;
  enumerator: string;
  updated_at: string;
  created_at: string;
  parts: Part[];
};

export type Part = {
  id: number;
  car_id: number;
  part_status_id: number;
  part_type_id: number;
  description: string;
  price: number;
  updated_at: string;
  created_at: string;
  car: Car;
  part_status: PartStatus;
  part_type: PartType;
  purchases: Purchase[];
  PurchasePart: PurchasePart[];
};

export type PurchaseStatus = {
  id: number;
  enumerator: string;
  updated_at: string;
  created_at: string;
  purchases: Purchase[];
};

export type Purchase = {
  id: number;
  description: string;
  updated_at: string;
  created_at: string;
  buyer_id: number;
  buyer: Buyer;
  purchase_parts: PurchasePart[];
  canceled: CanceledPurchasePart[];
};

export type CanceledPurchasePart = {
  part_id: number;
  purchase_id: Purchase;
  part: Part;
};

export type PurchasePart = {
  purchase_id: number;
  seller_id: number;
  seller: Seller;
  part_id: number;
  purchase: Purchase;
  part: Part;
};
